@@ -80,7 +80,7 @@
 #' # query params are URL encoded for you, so DO NOT do it yourself
 #' ## if you url encode yourself, it gets double encoded, and that's bad
 #' (x <- HttpClient$new(url = "https://httpbin.org"))
-#' res <- x$get("get", query = list(a = 'hello world'), verbose = TRUE)
+#' res <- x$get("get", query = list(a = 'hello world'))
 
 HttpClient <- R6::R6Class(
   'HttpClient',
@@ -88,6 +88,7 @@ HttpClient <- R6::R6Class(
     url = NULL,
     opts = list(),
     proxies = list(),
+    auth = list(),
     headers = list(),
     handle = NULL,
 
@@ -104,6 +105,11 @@ HttpClient <- R6::R6Class(
       cat("  proxies: ", sep = "\n")
       if (length(self$proxies)) cat(paste("    -", purl(self$proxies)),
                                     sep = "\n")
+      cat("  auth: ", sep = "\n")
+      if (length(self$auth$userpwd)) {
+        cat(paste("    -", self$auth$userpwd), sep = "\n")
+        cat(paste("    - type: ", self$auth$httpauth), sep = "\n")
+      }
       cat("  headers: ", sep = "\n")
       for (i in seq_along(self$headers)) {
         cat(sprintf("    %s: %s", names(self$headers)[i],
@@ -112,7 +118,7 @@ HttpClient <- R6::R6Class(
       invisible(self)
     },
 
-    initialize = function(url, opts, proxies, headers, handle) {
+    initialize = function(url, opts, proxies, auth, headers, handle) {
       if (!missing(url)) self$url <- url
       if (!missing(opts)) self$opts <- opts
       if (!missing(proxies)) {
@@ -121,6 +127,7 @@ HttpClient <- R6::R6Class(
         }
         self$proxies <- proxies
       }
+      if (!missing(auth)) self$auth <- auth
       if (!missing(headers)) self$headers <- headers
       if (!missing(handle)) self$handle <- handle
       if (is.null(self$url) && is.null(self$handle)) {
@@ -136,13 +143,16 @@ HttpClient <- R6::R6Class(
         url = url,
         method = "get",
         options = list(
-          httpget = TRUE,
-          useragent = make_ua()
+          httpget = TRUE
         ),
-        headers = self$headers
+        headers = list(
+          `User-Agent` = make_ua(),
+          `Accept-Encoding` = 'gzip, deflate'
+        )
       )
-      rr$options <- utils::modifyList(rr$options,
-                                      c(self$opts, self$proxies, ...))
+      rr$headers <- norm_headers(rr$headers, self$headers)
+      rr$options <- utils::modifyList(
+        rr$options, c(self$opts, self$proxies, self$auth, ...))
       rr$disk <- disk
       rr$stream <- stream
       private$make_request(rr)
@@ -228,7 +238,14 @@ HttpClient <- R6::R6Class(
       }
       curl::handle_setheaders(opts$url$handle, .list = opts$headers)
       on.exit(curl::handle_reset(opts$url$handle), add = TRUE)
-      resp <- crul_fetch(opts)
+
+      if (crul_opts$mock) {
+        check_for_package("webmockr")
+        adap <- webmockr::CrulAdapter$new()
+        return(adap$handle_request(opts))
+      } else {
+        resp <- crul_fetch(opts)
+      }
 
       HttpResponse$new(
         method = opts$method,
@@ -239,7 +256,12 @@ HttpClient <- R6::R6Class(
           if (grepl("^ftp://", resp$url)) {
             list()
           } else {
-            headers_parse(curl::parse_headers(rawToChar(resp$headers)))
+            hh <- rawToChar(resp$headers %||% raw(0))
+            if (is.null(hh) || nchar(hh) == 0) {
+              list()
+            } else {
+              headers_parse(curl::parse_headers(hh))
+            }
           }
         },
         modified = resp$modified,
