@@ -25,15 +25,35 @@ prep_opts <- function(method, url, self, opts, ...) {
     url = url,
     method = method,
     options = as.list(c(
-      opts$opts,
-      useragent = make_ua()
+      opts$opts
+    )),
+    headers = as.list(c(
+      opts$type,
+      `User-Agent` = make_ua(),
+      `Accept-Encoding` = 'gzip, deflate'
     )),
-    headers = c(self$headers, opts$type),
     fields = opts$fields
   )
+  rr$headers <- norm_headers(rr$headers, self$headers)
   rr$options <- utils::modifyList(
     rr$options,
-    c(self$opts, self$proxies, ...)
+    c(self$opts, self$proxies, self$auth, ...)
   )
   return(rr)
 }
+
+norm_headers <- function(x, y) {
+  if (length(names(y)) > 0) {
+    x <- x[!names(x) %in% names(y)]
+    x <- c(x, y)
+  }
+  return(x)
+}
+
+check_for_package <- function(x) {
+  if (!requireNamespace(x, quietly = TRUE)) {
+    stop(sprintf("Please install '%s'", x), call. = FALSE)
+  } else {
+    invisible(TRUE)
+  }
+}
